==> irm_1.4.3.orig.tar.gz: irm-1.4.3/users/setup-groups-del.php <==
<?php
#    IRM - The Information Resource Manager
#    Copyright (C) 1999 Yann Ramin
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License (in file COPYING) for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
#    $Id: setup-groups-del.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
#
################################################################################
#                                  CHANGELOG                                   #
################################################################################
#  8/16/99 - Keith Schoenefeld:	Added this file for group stuff                #
################################################################################

include("../include/irm.inc");

AuthCheck("tech");

commonHeader("IRM Group Setup - Group Deleted");
$query = "DELETE FROM groups WHERE (ID = \"$id\")";
$count = $adb->dbh_do($query);
$query = "DELETE FROM comp_group WHERE (group_id = \"$id\")";
$count = $adb->dbh_do($query);
?>
Group <?php echo "($id) $groupname"; ?> Deleted!  Note: All tracking for this 
<?php
PRINT "group has not been deleted. <a href=\"$USERPREFIX/setup-groups.php\">Go Back</a>";
commonFooter();
?>

==> irm_1.5.3.1.orig.tar.gz: irm-1.5.3.1/users/setup-groups-del.php <==
<?php
#    IRM - The Information Resource Manager
#    Copyright (C) 1999 Yann Ramin
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License (in file COPYING) for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
################################################################################

include("../include/irm.inc");
require_once 'lib/Config.php';
require_once 'include/i18n.php';

AuthCheck("tech");

commonHeader(_("Group Setup") . " - " . _("Group Deleted"));
$DB = Config::Database();
$qid = $DB->getTextValue($id);
$query = "DELETE FROM groups WHERE (ID = $qid)";
$DB->query($query);
$query = "DELETE FROM comp_group WHERE (group_id = $qid)";
$DB->query($query);

printf(_("Group (%s) %s Deleted!  Note: All tracking for this group has not been deleted."), $id, $groupname);
PRINT "<a href=\"".Config::AbsLoc('users/setup-groups.php')."\">"._("Go Back")."</a>";

commonFooter();
